@@ -107,7 +107,7 @@ async def start_app(app: FastAPI):
     setup_db(app)
     setup_storage(app)
     try:
-        from fa_common.gitlab import setup_gitlab
+        from fa_common.workflow import setup_gitlab
 
         setup_gitlab(app)
     except ValueError:
