@@ -3,11 +3,13 @@ import os
 import pytest
 
 from fa_common.auth import AuthUser
-from fa_common.gitlab import get_gitlab_client
+from fa_common.workflow import get_workflow_client
 from fa_common import force_sync, logger as LOG
+from dotenv import load_dotenv
 
 dirname = os.path.dirname(__file__)
 env_file = os.path.join(dirname, ".env")
+secrets_env_file = os.path.join(dirname, ".env.secret")
 minio_env_file = os.path.join(dirname, ".env-minio")
 
 TEST_GITLAB_PROJECT = "test_user"
@@ -16,7 +18,11 @@ TEST_GITLAB_BRANCH = "test_project"
 
 def get_env_file() -> str:
     clean_env()
-    return env_file
+    if os.path.exists(secrets_env_file):
+        load_dotenv(dotenv_path=env_file)
+        return secrets_env_file
+    else:
+        return env_file
 
 
 @pytest.fixture(scope="module")
@@ -27,18 +33,36 @@ def env_path(scope="module") -> str:
 @pytest.fixture(scope="module")
 def minio_env_path(scope="module") -> str:
     clean_env()
-    return minio_env_file
+    if os.path.exists(secrets_env_file):
+        load_dotenv(dotenv_path=minio_env_file)
+        return secrets_env_file
+    else:
+        return minio_env_file
 
 
 @pytest.fixture
 def ensure_no_test_gitlab():
-    client = get_gitlab_client()
+    client = get_workflow_client()
     try:
-        project_id = force_sync(client.delete_project_by_name)(TEST_GITLAB_PROJECT)
-        LOG.info(f"Deleted {project_id}")
+        project = force_sync(client._get_project_by_name)(TEST_GITLAB_PROJECT)
+    except ValueError:
+        LOG.info(f"No project called {TEST_GITLAB_PROJECT}")
+        return
+
+    force_sync(client.delete_project)(project.id, True)
+    LOG.info(f"Deleted {project.id}")
+
+
+@pytest.fixture
+def ensure_test_gitlab():
+    client = get_workflow_client()
+    try:
+        return (force_sync(client._get_project_by_name)("test_user")).id
     except Exception as err:
-        LOG.warning(err)
-        pass
+        LOG.info(err)
+        project_id = force_sync(client.create_project)("test_user")
+        force_sync(client.create_branch)(project_id, "test_project")
+        return project_id
 
 
 def clean_env():
